pub trait PeripheralInput<'d>: Into<InputSignal<'d>> + PeripheralSignal<'d> { }Expand description
A signal that can be connected to a peripheral input.
Peripheral drivers are encouraged to accept types that implement this and
PeripheralOutput as arguments instead of pin types.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl PeripheralInput<'_> for Level
Available on crate feature
unstable only.impl PeripheralInput<'_> for NoPin
Available on crate feature
unstable only.impl<'d> PeripheralInput<'d> for AnyPin<'d>
impl<'d> PeripheralInput<'d> for Flex<'d>
Available on crate feature
unstable only.Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
impl<'d> PeripheralInput<'d> for GPIO0<'d>
impl<'d> PeripheralInput<'d> for GPIO1<'d>
impl<'d> PeripheralInput<'d> for GPIO2<'d>
impl<'d> PeripheralInput<'d> for GPIO3<'d>
impl<'d> PeripheralInput<'d> for GPIO4<'d>
impl<'d> PeripheralInput<'d> for GPIO5<'d>
impl<'d> PeripheralInput<'d> for GPIO6<'d>
impl<'d> PeripheralInput<'d> for GPIO7<'d>
impl<'d> PeripheralInput<'d> for GPIO8<'d>
impl<'d> PeripheralInput<'d> for GPIO9<'d>
impl<'d> PeripheralInput<'d> for GPIO10<'d>
impl<'d> PeripheralInput<'d> for GPIO11<'d>
impl<'d> PeripheralInput<'d> for GPIO12<'d>
impl<'d> PeripheralInput<'d> for GPIO13<'d>
impl<'d> PeripheralInput<'d> for GPIO14<'d>
impl<'d> PeripheralInput<'d> for GPIO15<'d>
impl<'d> PeripheralInput<'d> for GPIO16<'d>
impl<'d> PeripheralInput<'d> for GPIO17<'d>
impl<'d> PeripheralInput<'d> for GPIO18<'d>
impl<'d> PeripheralInput<'d> for GPIO19<'d>
impl<'d> PeripheralInput<'d> for GPIO20<'d>
impl<'d> PeripheralInput<'d> for GPIO21<'d>
impl<'d> PeripheralInput<'d> for GPIO22<'d>
impl<'d> PeripheralInput<'d> for GPIO23<'d>
impl<'d> PeripheralInput<'d> for GPIO24<'d>
impl<'d> PeripheralInput<'d> for GPIO25<'d>
impl<'d> PeripheralInput<'d> for GPIO26<'d>
impl<'d> PeripheralInput<'d> for GPIO27<'d>
impl<'d> PeripheralInput<'d> for GPIO28<'d>
impl<'d> PeripheralInput<'d> for GPIO29<'d>
impl<'d> PeripheralInput<'d> for GPIO30<'d>
impl<'d> PeripheralInput<'d> for Input<'d>
Available on crate feature
unstable only.Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
impl<'d> PeripheralInput<'d> for InputSignal<'d>
Available on crate feature
unstable only.